%define pkg    lua
%define ver    5.1.4
%define maj    %(echo %{ver} | cut -d'.' -f1)
%define min    %(echo %{ver} | cut -d'.' -f2)
%define abiver %{maj}.%{min}
%define pkgid  %{maj}%{min}
%define pkgstr %{pkg}


Summary:       A powerful embeddable scripting language
Name:          %{pkgstr}
Version:       %{ver}
Release:       5%{?dist}%{?pext}
License:       MIT/X11
Group:         Development/Languages
Source0:       http://www.%{pkg}.org/ftp/%{pkg}-%{ver}.tar.gz
Patch0:        http://www.%{pkg}.org/ftp/patch-%{pkg}-5.1.4-4
Patch1:        %{pkg}-5.1.4-paths.patch
Patch2:        %{pkg}-5.1.3-dynamic.patch
URL:           http://www.%{pkg}.org/
Buildroot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:        The Lua Team <team@lua.org>
Requires:      %{name}-lib = %{version}-%{release}
BuildRequires: ncurses-devel readline-devel

%description
Lua is a powerful, fast, light-weight, embeddable scripting language. It
combines simple procedural syntax with powerful data description constructs
based on associative arrays and extensible semantics. Lua is dynamically
typed, runs by interpreting bytecode for a register-based virtual machine,
and has automatic memory management with incremental garbage collection,
making it ideal for configuration, scripting, and rapid prototyping.


%package       devel
Summary:       Development tools for Lua
Group:         Development/Libraries
Requires:      %{name}-lib = %{version}-%{release}
Requires:      pkgconfig
Obsoletes:     lib%{name}-devel < %{version}-%{release}

%description   devel
The %{name}-devel package contains the static libraries and header files
for developing software using Lua.


%package       lib
Summary:       The Lua interpreter library
Group:         System Environment/Libraries
Provides:      %{pkg}(abi) = %{abiver}
Obsoletes:     lib%{name} < %{version}-%{release}
Obsoletes:     %{name}-libs < %{version}-%{release}

%description   lib
The %{name}-lib package contains the Lua interpreter as shared library.


%prep
%setup -q
%patch0 -p0
%patch1 -p1
%patch2 -p1

# Fix config
for FILE in Makefile etc/lua.pc src/luaconf.h; do
  %{__sed} -i -e 's#XXX_PREFIX_XXX#%{_prefix}#g' \
	      -e 's#/lib#/%{_lib}#g'             \
	      -e 's#lib/lua#%{_lib}/lua#g'       \
	      -e 's#/man/#/share/man/#g' ${FILE}
done


%build
%{__make} \
	EXTRA_CFLAGS="${RPM_OPT_FLAGS}" \
	linux


%check
%{__make} test


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig

%{__make} \
	INSTALL_TOP=${RPM_BUILD_ROOT}%{_prefix} \
	install

%{__install} -m 0644 etc/lua.pc ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig

%{__rm} -f ${RPM_BUILD_ROOT}%{_libdir}/lib*.so.?


%post lib -p /sbin/ldconfig


%postun lib -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc COPYRIGHT HISTORY INSTALL README
%doc --parents doc/*.{css,gif,html,png}
%{_bindir}/lua
%{_bindir}/luac
%{_mandir}/man1/lua.1*
%{_mandir}/man1/luac.1*

%files devel
%defattr(-,root,root)
%{_includedir}/lua.hpp
%{_includedir}/lua*.h
%{_includedir}/lauxlib.h
%{_libdir}/liblua.a
%{_libdir}/liblua.so
%{_libdir}/pkgconfig/lua.pc

%files lib
%defattr(-,root,root)
%{_libdir}/liblua.so.*
%{_libdir}/lua
%{_datadir}/lua


%changelog
* Wed Dec 28 2011 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.4-5
- Added upstream bugfixes

* Mon Apr 04 2011 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.4-4
- Added upstream bugfixes

* Fri May 21 2010 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.4-3
- Added upstream bugfixes

* Fri Aug 21 2009 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.4-2
- Provide ABI version
- Fixed missing requires

* Sat Oct 04 2008 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.4-1
- New version (5.1.4)

* Mon Apr 14 2008 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.3-2
- Added missing pkgconfig script

* Sun Apr 13 2008 Peter Pramberger <peterpramb@member.fsf.org> - 5.1.3-1
- Initial build
